==> soma-job-history-consumer-0.2.0-sources.jar: br/pucrio/tecgraf/soma/job/application/service/job/JobService.java <==
package br.pucrio.tecgraf.soma.job.application.service.job;

import br.pucrio.tecgraf.soma.job.*;
import br.pucrio.tecgraf.soma.job.application.service.job.builder.*;
import br.pucrio.tecgraf.soma.job.infrastructure.persistence.specification.JobByIdSpecification;
import br.pucrio.tecgraf.soma.job.domain.model.Job;
import br.pucrio.tecgraf.soma.serviceapi.persistence.repository.Repository;
import br.pucrio.tecgraf.soma.serviceapi.persistence.specification.JPASpecification;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.io.IOException;
import java.text.MessageFormat;

@Service
public class JobService {

	private final Logger logger = LoggerFactory.getLogger(JobService.class);

	private Repository<Job, JPASpecification<Job>> jobRepository;

	@Autowired
	public JobService(Repository<Job, JPASpecification<Job>> jobRepository) {
		this.jobRepository = jobRepository;
	}

	@Transactional
	public void scheduleJob(JobScheduledEvent scheduledEvent) throws IOException {
    try {
      logEvent(scheduledEvent.getJobId(), Constants.JOB_SCHEDULED_EVENT, scheduledEvent.getEventId());
      Job job = new Job();
      new ScheduledJobBuilder().build(job, scheduledEvent);
      jobRepository.add(job);
    } catch (Exception e) {
      throw createIOException(
          scheduledEvent.getJobId(),
          Constants.JOB_SCHEDULED_EVENT,
          scheduledEvent.getEventId(),
          e);
    }
  }

  @Transactional
	public void rescheduleJob(JobRescheduledEvent rescheduledEvent) throws IOException {
    try {
      logEvent(rescheduledEvent.getJobId(), Constants.JOB_RESCHEDULED_EVENT, rescheduledEvent.getEventId());
      Job job = findJob(rescheduledEvent.getJobId());
      new RescheduledJobBuilder().build(job, rescheduledEvent);
    } catch (Exception e) {
      throw createIOException(
          rescheduledEvent.getJobId(),
          Constants.JOB_RESCHEDULED_EVENT,
          rescheduledEvent.getEventId(),
          e);
    }
  }

  @Transactional
	public void stageJobIn(JobStageInEvent stageInEvent) throws IOException {
		logEvent(stageInEvent.getJobId(), Constants.JOB_STAGEIN_EVENT, stageInEvent.getEventId());
		try {
			Job job = findJob(stageInEvent.getJobId());
			new StageInJobBuilder().build(job, stageInEvent);
    } catch (Exception e) {
      throw createIOException(
          stageInEvent.getJobId(),
          Constants.JOB_STAGEIN_EVENT,
          stageInEvent.getEventId(),
          e);
    }
	}

  @Transactional
  public void stageJobOut(JobStageOutEvent stageOutEvent) throws IOException {
		logEvent(stageOutEvent.getJobId(), Constants.JOB_STAGEOUT_EVENT, stageOutEvent.getEventId());
		try {
			Job job = findJob(stageOutEvent.getJobId());
			new StageOutJobBuilder().build(job, stageOutEvent);
    } catch (Exception e) {
      throw createIOException(
          stageOutEvent.getJobId(),
          Constants.JOB_STAGEOUT_EVENT,
          stageOutEvent.getEventId(),
          e);
    }
	}

  @Transactional
  public void executeJob(JobExecutingEvent executingEvent) throws IOException {
		logEvent(executingEvent.getJobId(), Constants.JOB_EXECUTING_EVENT, executingEvent.getEventId());
		try {
			Job job = findJob(executingEvent.getJobId());
			new ExecutingJobBuilder().build(job, executingEvent);
    } catch (Exception e) {
      throw createIOException(
          executingEvent.getJobId(),
          Constants.JOB_EXECUTING_EVENT,
          executingEvent.getEventId(),
          e);
    }
	}

  @Transactional
  public void finishJob(JobFinishedEvent finishedEvent) throws IOException {
		logEvent(finishedEvent.getJobId(), Constants.JOB_FINISHED_EVENT, finishedEvent.getEventId());
		try {
			Job job = findJob(finishedEvent.getJobId());
			new FinishedJobBuilder().build(job, finishedEvent);
    } catch (Exception e) {
      throw createIOException(
          finishedEvent.getJobId(),
          Constants.JOB_FINISHED_EVENT,
          finishedEvent.getEventId(),
          e);
    }
	}

  private Job findJob(String jobId) {
    Job job = jobRepository.first(new JobByIdSpecification(jobId));
    if (job == null) {
      throw new RuntimeException("Cannot find a job with JobId= " + jobId + ".");
    }
    return job;
  }

	private void logEvent(String jobId, String eventType, String eventId){
		logger.info("[Job={}, event type={}, event id={}]", jobId, eventType, eventId);
	}

  private IOException createIOException(
      String jobId, String eventType, String eventId, Exception e) {
    return new IOException(
        MessageFormat.format(
            "Error processing event type {0} for job {1}. [event id={2}].",
            eventType,
            jobId,
            eventId),
        e);
  }
}

==> soma-job-history-consumer-0.3.0-sources.jar: br/pucrio/tecgraf/soma/job/application/service/job/JobService.java <==
package br.pucrio.tecgraf.soma.job.application.service.job;

import br.pucrio.tecgraf.soma.job.*;
import br.pucrio.tecgraf.soma.job.application.service.job.builder.*;
import br.pucrio.tecgraf.soma.job.infrastructure.persistence.specification.JobByIdSpecification;
import br.pucrio.tecgraf.soma.job.domain.model.Job;
import br.pucrio.tecgraf.soma.serviceapi.persistence.repository.Repository;
import br.pucrio.tecgraf.soma.serviceapi.persistence.specification.JPASpecification;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.io.IOException;
import java.text.MessageFormat;

@Service
public class JobService {

	private final Logger logger = LoggerFactory.getLogger(JobService.class);

	private Repository<Job, JPASpecification<Job>> jobRepository;

	@Autowired
	public JobService(Repository<Job, JPASpecification<Job>> jobRepository) {
		this.jobRepository = jobRepository;
	}

	@Transactional
	public void scheduleJob(JobScheduledEvent scheduledEvent) throws IOException {
    try {
      logEvent(scheduledEvent.getJobId(), Constants.JOB_SCHEDULED_EVENT, scheduledEvent.getEventId());
      Job job = new Job();
      new ScheduledJobBuilder().build(job, scheduledEvent);
      jobRepository.add(job);
    } catch (Exception e) {
      throw createIOException(
          scheduledEvent.getJobId(),
          Constants.JOB_SCHEDULED_EVENT,
          scheduledEvent.getEventId(),
          e);
    }
  }

  @Transactional
	public void rescheduleJob(JobRescheduledEvent rescheduledEvent) throws IOException {
    try {
      logEvent(rescheduledEvent.getJobId(), Constants.JOB_RESCHEDULED_EVENT, rescheduledEvent.getEventId());
      Job job = findJob(rescheduledEvent.getJobId());
      new RescheduledJobBuilder().build(job, rescheduledEvent);
    } catch (Exception e) {
      throw createIOException(
          rescheduledEvent.getJobId(),
          Constants.JOB_RESCHEDULED_EVENT,
          rescheduledEvent.getEventId(),
          e);
    }
  }

  @Transactional
	public void stageJobIn(JobStageInEvent stageInEvent) throws IOException {
		logEvent(stageInEvent.getJobId(), Constants.JOB_STAGEIN_EVENT, stageInEvent.getEventId());
		try {
			Job job = findJob(stageInEvent.getJobId());
			new StageInJobBuilder().build(job, stageInEvent);
    } catch (Exception e) {
      throw createIOException(
          stageInEvent.getJobId(),
          Constants.JOB_STAGEIN_EVENT,
          stageInEvent.getEventId(),
          e);
    }
	}

  @Transactional
  public void stageJobOut(JobStageOutEvent stageOutEvent) throws IOException {
		logEvent(stageOutEvent.getJobId(), Constants.JOB_STAGEOUT_EVENT, stageOutEvent.getEventId());
		try {
			Job job = findJob(stageOutEvent.getJobId());
			new StageOutJobBuilder().build(job, stageOutEvent);
    } catch (Exception e) {
      throw createIOException(
          stageOutEvent.getJobId(),
          Constants.JOB_STAGEOUT_EVENT,
          stageOutEvent.getEventId(),
          e);
    }
	}

  @Transactional
  public void executeJob(JobExecutingEvent executingEvent) throws IOException {
		logEvent(executingEvent.getJobId(), Constants.JOB_EXECUTING_EVENT, executingEvent.getEventId());
		try {
			Job job = findJob(executingEvent.getJobId());
			new ExecutingJobBuilder().build(job, executingEvent);
    } catch (Exception e) {
      throw createIOException(
          executingEvent.getJobId(),
          Constants.JOB_EXECUTING_EVENT,
          executingEvent.getEventId(),
          e);
    }
	}

  @Transactional
  public void finishJob(JobFinishedEvent finishedEvent) throws IOException {
		logEvent(finishedEvent.getJobId(), Constants.JOB_FINISHED_EVENT, finishedEvent.getEventId());
		try {
			Job job = findJob(finishedEvent.getJobId());
			new FinishedJobBuilder().build(job, finishedEvent);
    } catch (Exception e) {
      throw createIOException(
          finishedEvent.getJobId(),
          Constants.JOB_FINISHED_EVENT,
          finishedEvent.getEventId(),
          e);
    }
	}

  @Transactional
  public void progressUpdate(JobProgressEvent progressEvent) throws IOException {
		logEvent(progressEvent.getJobId(), Constants.JOB_PROGRESS_EVENT, progressEvent.getEventId());
		try {
			Job job = findJob(progressEvent.getJobId());
			new JobProgressBuilder().build(job, progressEvent);
    } catch (Exception e) {
      throw createIOException(
        progressEvent.getJobId(),
          Constants.JOB_PROGRESS_EVENT,
          progressEvent.getEventId(),
          e);
    }
	}

  private Job findJob(String jobId) {
    Job job = jobRepository.first(new JobByIdSpecification(jobId));
    if (job == null) {
      throw new RuntimeException("Cannot find a job with JobId= " + jobId + ".");
    }
    return job;
  }

	private void logEvent(String jobId, String eventType, String eventId){
		logger.info("[Job={}, event type={}, event id={}]", jobId, eventType, eventId);
	}

  private IOException createIOException(
      String jobId, String eventType, String eventId, Exception e) {
    return new IOException(
        MessageFormat.format(
            "Error processing event type {0} for job {1}. [event id={2}].",
            eventType,
            jobId,
            eventId),
        e);
  }
}
